import React, { useState, useEffect } from 'react';
import axios from 'axios';
import helper from '../config/helperConfig';
import * as skyid from 'skyid-sdk-web';

const SkyIdentification = () => {
  const [selectedFile, setSelectedFile] = useState(null);
  const [responseLogin, setResponseLogin] = useState(null);
  const [responseLiveness, setResponseLiveness] = useState(null);
  const [responseFaceMatching, setResponseFaceMatching] = useState(null);
  const [displaybtn, setdisplaybtn] = useState(null);
  const [imageSrc, setImageSrc] = useState("/assets/CINcrt.jpg");

  const handleFileChange = (event) => {
    readImage(event.target.files[0]);
  };

  const readImage = (file) => {
    const reader = new FileReader();
    reader.readAsDataURL(file);
    setSelectedFile(file);
    reader.onload = function () {
      setImageSrc(reader.result);
  };
    init();
  };

  const login = async () => {
    const formData = new FormData();
    formData.append("username", helper.skyid_fa_sdk_user);
    formData.append("password", helper.skyid_fa_sdk_password);
    axios.post(helper.skyid_fa_sdk_params_url+"login", formData)
      .then(response => {
        setResponseLogin(response.data);
        if (response.data.status_code === "000") {
          get_parameters(response.data.response_data.access_token);
        }
      })
      .catch(error => {
        console.error('Error login', error);
      });
  };

  const get_parameters = async (bearToken) => {
    const formData = new FormData();
    formData.append("token", helper.skyid_fa_sdk_token);
    formData.append("application_id", helper.skyid_fa_sdk_appId);
    axios.post(helper.skyid_fa_sdk_params_url+"get_parameters_web_sdk", formData, {
      headers: {
        Authorization: `Bearer ${bearToken}`,
        'Content-Type': 'multipart/form-data',
      }
    })
      .then(response => {
        console.log('get_params success', response.data);
        if (response.data.status_code === "000") {
          skyid.skyid_fa_init_sdk(response.data.response_data);
        }
      })
      .catch(error => {
        console.error('get_params error', error);
      });
  };

  const startScanFace = () => {
    skyid.skyid_fa_start_face_scan(skyidFaFaceScanEndCallback, processFaTimeOut);
  };

  const skyidFaFaceScanEndCallback = async (frame) => {
    const face_image = helper.setFileImage(frame);
    const formData = new FormData();
    const bearToken = responseLogin.response_data.access_token;
    formData.append("selfie", face_image);
    axios.post(helper.LIVENESS_url, formData, {
      headers: {
        Authorization: `Bearer ${bearToken}`,
        'Content-Type': 'multipart/form-data',
      }
    })
      .then(response => {
        console.log('ocr success', response.data);
        if (response.data.status_code === "000") {
          setResponseLiveness(response.data);
          skyid.skyid_fa_start_face_scan(skyid_face_scan_end_callbackfacematching, processFaTimeOut);
        }
      })
      .catch(error => {
        console.error('ocr error', error);
        window.location.reload()
      });
  };

  const skyid_face_scan_end_callbackfacematching = async (frame) => {
    const face_image = helper.setFileImage(frame);
    const formData = new FormData();
    const bearToken = responseLogin.response_data.access_token;
    formData.append("doc_1_1", selectedFile);
    formData.append("slf_1", face_image);
    formData.append('guid', "101010303");
    formData.append("token", helper.skyid_fa_sdk_token);
    formData.append("application_id", helper.skyid_fa_sdk_appId);
    axios.post(helper.FACE_MATCHING_url, formData, {
      headers: {
        Authorization: `Bearer ${bearToken}`,
        'Content-Type': 'multipart/form-data',
      }
    })
      .then(response => {
        console.log('ocr success', response.data);
        if (response.data.status_code === "000") {
          setResponseFaceMatching(response.data);
          skyid.skyid_fa_stop_webcam();
        }
      })
      .catch(error => {
        console.error('ocr error', error);
        skyid.skyid_fa_stop_webcam();
        window.location.reload()
      });

  };

  const processFaTimeOut = () => {
    console.log("processFaTimeOut");
  };

  const init = () => {
    setdisplaybtn(true);
    let skyid_liveness = document.getElementById('skyid_liveness');
    skyid_liveness.innerHTML = skyid.skyid_component;
    skyid.skyid_fa_setup_sdk();
  }

  useEffect(() => {
    login();
  }, []);

  return (
    <div className="main_container">
      <br/>
      <div>
        <img src="/assets/IndatacoreIdentity.png" className="IndatacoreIdentity" alt="" />
      </div>

      <h1>It only takes one more click to discover Sky FaceAnalysis on the web channel.</h1>

      <div id="multi-step-form-container">

        <input type="file" onChange={handleFileChange} />
        <img src={`${imageSrc}`} />

        <br/>
        {responseLogin && (
          <div className='code-json'>
          <br/>
            <h2>Server Response Login :</h2>
            <pre>{JSON.stringify(responseLogin, null, 2)}</pre>
          </div>
        )}
        <br/>
        <div id="skyid_liveness"></div>
        <br/>
        {displaybtn && (
          <button  onClick={startScanFace}>Start Scan Face</button>
        )}
        <div className='code-json'>
        <br />
          {responseLiveness && (
            <div>
              <h2>Server Response Liveness:</h2>
              <pre>{JSON.stringify(responseLiveness, null, 2)}</pre>
            </div>
          )}
        </div>
        <br />
        <div>
          {responseFaceMatching && (
            <div className='code-json'>
              <h2>Server Response Face Matching :</h2>
              <pre>{JSON.stringify(responseFaceMatching, null, 2)}</pre>
            </div>
          )}
        </div>

      </div>



    </div>
  );
};

export default SkyIdentification;
